@@ -503,6 +503,7 @@ def identifyTable(cond0, cond1, tab0, tab1, res, other):
     cond1 = cond1.setSource(tab0, tab1)
     leftover0 = cond0 - cond1
     leftover1 = cond1 - cond0
+    commontables = (cond0 | cond1).getTables()
     
     for expr0 in andcond.baseExprs().filter(lambda x: (x.table == tab0)):# & x.isPrimary()):
         for expr1 in andcond.baseExprs().filter(lambda x: (x.table == tab1)):# & x.isPrimary()):
@@ -511,8 +512,9 @@ def identifyTable(cond0, cond1, tab0, tab1, res, other):
                     if leftover0 and tab1.leftjoin and not tab0.leftjoin:
                         return False
                     if leftover1 and tab0.leftjoin and not tab1.leftjoin:
-                        return False
-                    return leftover0.getTables() <= L(tab0) and leftover1.getTables() <= L(tab0) + other.getTables()
+                        return False                    
+                    return leftover0.getTables() <= commontables and leftover1.getTables() <= commontables
+                    # return leftover0.getTables() <= L(tab0) and leftover1.getTables() <= L(tab0) + other.getTables()
     return False
 
 
