@@ -1,5 +1,6 @@
 from LambdaQuery.expr import *
 from LambdaQuery.misc import *
+from LambdaQuery.query import addQuery
 from itertools import product
 
 def addParents(self, reset=False, debug=False):
@@ -469,22 +470,31 @@ def mergeGrouped(self, debug=False, subquery=False):
     
     for tablegroup in alltablegroups:
         
-        merged = tablegroup.fold(lambda x, y: x @ y)
-        
-        self.setSource(merged, oldtable=tablegroup)
+        # if self in tablegroup, then use the columns = 'left' option in addquery. 
+        # then modify columns ith mergeexpr
         
         if self in tablegroup:
-            
-            # moveInHaving(inner=table, outer=self)
-            
-            # merge with a subquery and convert the agg exprs
+            merged = tablegroup.fold(lambda x, y: addQuery(x, y, addcols='left'))
             merged.modify(lambda x: mergeExpr(x, oldtables=tablegroup))
-            self.modify(lambda x: mergeExpr(x, oldtables=L(merged)))
-            merged.columns = self.columns
             self.__dict__.update(merged.__dict__)
-            break
+        else:
+            merged = tablegroup.fold(lambda x, y: x @ y)
+            self.setSource(merged, oldtable=tablegroup)
+        
+        # if self not in tablegroup:
+        
+        # if self in tablegroup:
+            
+        #     # moveInHaving(inner=table, outer=self)
+            
+        #     # merge with a subquery and convert the agg exprs
+        #     merged.modify(lambda x: mergeExpr(x, oldtables=tablegroup))
+        #     # self.modify(lambda x: mergeExpr(x, oldtables=L(merged)))
+        #     # merged.columns = self.columns
+        #     self.__dict__.update(merged.__dict__)
+        #     break
     
-    if alltablegroups:
+    if alltablegroups and self.subQueries():
         mergeGrouped(self)
     
     # for subtable in self.subQueries():
@@ -492,6 +502,9 @@ def mergeGrouped(self, debug=False, subquery=False):
 
 def mergeExpr(expr, oldtables):
     res = expr.getRef(oldtables=oldtables)
+    
+    
+    
     # if AndExpr(expr.baseExprs().filter(lambda x: x.table.leftjoin).fmap(Expr._isnull_)).children:        
     return res
 
